=== modified file 'lib/lp/registry/browser/distroseries.py'
--- lib/lp/registry/browser/distroseries.py	2011-08-01 20:25:28 +0000
+++ lib/lp/registry/browser/distroseries.py	2011-08-04 14:17:38 +0000
@@ -1078,17 +1078,23 @@
             ALL: DistroSeriesDifferenceStatus.items,
         }
 
-        status = package_type_dsd_status[self.specified_package_type]
-        child_version_higher = (
-            self.specified_package_type == HIGHER_VERSION_THAN_PARENT)
+        # If the package_type option is not supported, add an error to
+        # the field and return an empty list.
+        if self.specified_package_type not in package_type_dsd_status:
+            self.setFieldError('package_type', 'Invalid option')
+            differences = []
+        else:
+            status = package_type_dsd_status[self.specified_package_type]
+            child_version_higher = (
+                self.specified_package_type == HIGHER_VERSION_THAN_PARENT)
+            differences = getUtility(
+                IDistroSeriesDifferenceSource).getForDistroSeries(
+                    self.context, difference_type=self.differences_type,
+                    name_filter=self.specified_name_filter,
+                    status=status, child_version_higher=child_version_higher,
+                    packagesets=self.specified_packagesets_filter,
+                    changed_by=self.specified_changed_by_filter)
 
-        differences = getUtility(
-            IDistroSeriesDifferenceSource).getForDistroSeries(
-                self.context, difference_type=self.differences_type,
-                name_filter=self.specified_name_filter,
-                status=status, child_version_higher=child_version_higher,
-                packagesets=self.specified_packagesets_filter,
-                changed_by=self.specified_changed_by_filter)
         return BatchNavigator(differences, self.request)
 
     @cachedproperty

=== modified file 'lib/lp/registry/browser/tests/test_distroseries.py'
--- lib/lp/registry/browser/tests/test_distroseries.py	2011-07-29 20:05:40 +0000
+++ lib/lp/registry/browser/tests/test_distroseries.py	2011-08-04 14:17:38 +0000
@@ -1637,6 +1637,23 @@
 
         self.assertContentEqual(diffs, all_view.cached_differences.batch)
 
+    def test_batch_wrong_param(self):
+        # If a wrong parameter is passed then an error is displayed
+        # and no differences are shown.
+        set_derived_series_ui_feature_flag(self)
+        derived_series, parent_series = self._createChildAndParent()
+        self.factory.makeDistroSeriesDifference(
+            derived_series=derived_series,
+            source_package_name_str="my-src-package")
+        view = create_initialized_view(
+            derived_series,
+            '+localpackagediffs',
+            query_string='field.package_type=%s' % 'unexpected')
+        view()  # Render the view.
+
+        self.assertEqual('Invalid option', view.getFieldError('package_type'))
+        self.assertContentEqual([], view.cached_differences.batch)
+
     def test_batch_blacklisted_differences_with_higher_version(self):
         # field.package_type parameter allows to list only
         # blacklisted differences with a child's version higher than parent's.

=== modified file 'lib/lp/registry/templates/packagesearch-macros.pt'
--- lib/lp/registry/templates/packagesearch-macros.pt	2011-08-04 09:01:27 +0000
+++ lib/lp/registry/templates/packagesearch-macros.pt	2011-08-04 18:33:35 +0000
@@ -65,16 +65,21 @@
     <div style="float:left; margin-right:1px;">
       <label for="field.name_filter">Show packages or packagesets named:</label>
     </div>
-    <div style="float:left;">
+    <div style="float:left;"
+      tal:define="widget nocall:view/widgets/package_type;
+                  field_name widget/context/__name__;
+                  error python:view.getFieldError(field_name);">
       <input
         id="field.name_filter" title="Package Name" size="20"
         type="text" name="field.name_filter"
         tal:attributes="value request/field.name_filter|nothing"/>
       <input type="submit" value="Filter" />
-     <br />
-     <tal:package_type
-       replace="structure view/widgets/package_type" />
-    </div>
+      <br />
+      <tal:package_type
+        replace="structure widget" />
+      <div class="error message" tal:condition="error"
+        tal:content="structure error">Error message</div>
+      </div>
     <div class="clearfix"></div>
   </form>
 

